@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procmem.h,v 1.13 1999/02/23 11:43:08 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -46,15 +44,15 @@ typedef struct _glibtop_proc_mem	glibtop_proc_mem;
 
 struct _glibtop_proc_mem
 {
-    u_int64_t	flags,
-	size,		/* total # of pages of memory */
-	vsize,		/* number of pages of virtual memory ... */
-	resident,	/* number of resident set
-			 * (non-swapped) pages (4k) */
-	share,		/* number of pages of shared (mmap'd) memory */
-	rss,		/* resident set size */
-	rss_rlim;	/* current limit (in bytes) of the rss
-			 * of the process; usually 2,147,483,647 */
+	u_int64_t	flags,
+		size,		/* total # of pages of memory */
+		vsize,		/* number of pages of virtual memory ... */
+		resident,	/* number of resident set
+				 * (non-swapped) pages (4k) */
+		share,		/* number of pages of shared (mmap'd) memory */
+		rss,		/* resident set size */
+		rss_rlim;	/* current limit (in bytes) of the rss
+				 * of the process; usually 2,147,483,647 */
 };
 
 #define glibtop_get_proc_mem(p1, p2)	glibtop_get_proc_mem_l(glibtop_global_server, p1, p2)
@@ -65,14 +63,14 @@ struct _glibtop_proc_mem
 #define glibtop_get_proc_mem_r		glibtop_get_proc_mem_s
 #endif
 
-int glibtop_get_proc_mem_l (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
+void glibtop_get_proc_mem_l (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_MEM
-int glibtop_init_proc_mem_p (glibtop *server);
-int glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
+void glibtop_init_proc_mem_p (glibtop *server);
+void glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 #else
-int glibtop_init_proc_mem_s (glibtop *server);
-int glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
+void glibtop_init_proc_mem_s (glibtop *server);
+void glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
