@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: sem_limits.c,v 1.6 1999/02/23 11:46:34 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,20 +28,16 @@ static const unsigned long _glibtop_sysdeps_sem_limits = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_sem_limits_s (glibtop *server)
 {
-    server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
-
-    return 0;
+	server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
 }
 
 /* Provides information about sysv sem limits. */
 
-int
+void
 glibtop_get_sem_limits_s (glibtop *server, glibtop_sem_limits *buf)
 {
-    memset (buf, 0, sizeof (glibtop_sem_limits));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_sem_limits));
 }
