@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: swap.c,v 1.8 1999/02/23 11:47:34 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,10 +28,10 @@
 
 /* Provides information about swap usage. */
 
-int
+void
 glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 {
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
+	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_SWAP), 0);
 
-    memset (buf, 0, sizeof (glibtop_swap));
+	memset (buf, 0, sizeof (glibtop_swap));
 }
